# BHPQ - Binary Heap Priority Queue

A binary heap priority queue implementation

## Installation

You can install bhpq from [PyPI](https://pypi.org/project/bhpq):

    pip install bhpq

bhpq is supported on Python 2.7, as well as Python 3.4 and above.

## Usage

    from bhpq import BinaryHeapPriorityQueue
